@@ -10,7 +10,6 @@ from typing import Sequence
 from narwhals._compliant import LazyExpr
 from narwhals._compliant.expr import DepthTrackingExpr
 from narwhals._dask.expr_dt import DaskExprDateTimeNamespace
-from narwhals._dask.expr_name import DaskExprNameNamespace
 from narwhals._dask.expr_str import DaskExprStringNamespace
 from narwhals._dask.utils import add_row_index
 from narwhals._dask.utils import maybe_evaluate_expr
@@ -25,19 +24,22 @@ from narwhals.utils import generate_temporary_column_name
 from narwhals.utils import not_implemented
 
 if TYPE_CHECKING:
-    from narwhals._expression_parsing import ExprKind
-
-    try:
-        import dask.dataframe.dask_expr as dx
-    except ModuleNotFoundError:
-        import dask_expr as dx
-
+    import dask.dataframe.dask_expr as dx
     from typing_extensions import Self
 
+    from narwhals._compliant.typing import AliasNames
+    from narwhals._compliant.typing import EvalNames
+    from narwhals._compliant.typing import EvalSeries
     from narwhals._dask.dataframe import DaskLazyFrame
     from narwhals._dask.namespace import DaskNamespace
+    from narwhals._expression_parsing import ExprKind
     from narwhals._expression_parsing import ExprMetadata
     from narwhals.dtypes import DType
+    from narwhals.typing import FillNullStrategy
+    from narwhals.typing import NonNestedLiteral
+    from narwhals.typing import NumericLiteral
+    from narwhals.typing import RollingInterpolationMethod
+    from narwhals.typing import TemporalLiteral
     from narwhals.utils import Version
     from narwhals.utils import _FullContext
 
@@ -49,13 +51,13 @@ class DaskExpr(
     _implementation: Implementation = Implementation.DASK
 
     def __init__(
-        self: Self,
-        call: Callable[[DaskLazyFrame], Sequence[dx.Series]],
+        self,
+        call: EvalSeries[DaskLazyFrame, dx.Series],
         *,
         depth: int,
         function_name: str,
-        evaluate_output_names: Callable[[DaskLazyFrame], Sequence[str]],
-        alias_output_names: Callable[[Sequence[str]], Sequence[str]] | None,
+        evaluate_output_names: EvalNames[DaskLazyFrame],
+        alias_output_names: AliasNames | None,
         backend_version: tuple[int, ...],
         version: Version,
         # Kwargs with metadata which we may need in group-by agg
@@ -72,7 +74,7 @@ class DaskExpr(
         self._call_kwargs = call_kwargs or {}
         self._metadata: ExprMetadata | None = None
 
-    def __call__(self: Self, df: DaskLazyFrame) -> Sequence[dx.Series]:
+    def __call__(self, df: DaskLazyFrame) -> Sequence[dx.Series]:
         return self._call(df)
 
     def __narwhals_expr__(self) -> None: ...
@@ -83,20 +85,6 @@ class DaskExpr(
 
         return DaskNamespace(backend_version=self._backend_version, version=self._version)
 
-    def _with_metadata(self, metadata: ExprMetadata) -> Self:
-        expr = self.__class__(
-            self._call,
-            function_name=self._function_name,
-            evaluate_output_names=self._evaluate_output_names,
-            alias_output_names=self._alias_output_names,
-            backend_version=self._backend_version,
-            version=self._version,
-            depth=self._depth,
-            call_kwargs=self._call_kwargs,
-        )
-        expr._metadata = metadata
-        return expr
-
     def broadcast(self, kind: Literal[ExprKind.AGGREGATION, ExprKind.LITERAL]) -> Self:
         def func(df: DaskLazyFrame) -> list[dx.Series]:
             return [result[0] for result in self(df)]
@@ -115,7 +103,7 @@ class DaskExpr(
     @classmethod
     def from_column_names(
         cls: type[Self],
-        evaluate_column_names: Callable[[DaskLazyFrame], Sequence[str]],
+        evaluate_column_names: EvalNames[DaskLazyFrame],
         /,
         *,
         context: _FullContext,
@@ -165,11 +153,12 @@ class DaskExpr(
             version=context._version,
         )
 
-    def _from_call(
-        self: Self,
+    def _with_callable(
+        self,
         # First argument to `call` should be `dx.Series`
         call: Callable[..., dx.Series],
-        expr_name: str,
+        /,
+        expr_name: str = "",
         call_kwargs: dict[str, Any] | None = None,
         **expressifiable_args: Self | Any,
     ) -> Self:
@@ -196,131 +185,125 @@ class DaskExpr(
             call_kwargs=call_kwargs,
         )
 
-    def alias(self: Self, name: str) -> Self:
-        def alias_output_names(names: Sequence[str]) -> Sequence[str]:
-            if len(names) != 1:
-                msg = f"Expected function with single output, found output names: {names}"
-                raise ValueError(msg)
-            return [name]
-
-        return self.__class__(
-            self._call,
+    def _with_alias_output_names(self, func: AliasNames | None, /) -> Self:
+        return type(self)(
+            call=self._call,
             depth=self._depth,
             function_name=self._function_name,
             evaluate_output_names=self._evaluate_output_names,
-            alias_output_names=alias_output_names,
+            alias_output_names=func,
             backend_version=self._backend_version,
             version=self._version,
             call_kwargs=self._call_kwargs,
         )
 
-    def __add__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __add__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__add__(other), "__add__", other=other
         )
 
-    def __sub__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __sub__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__sub__(other), "__sub__", other=other
         )
 
-    def __rsub__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __rsub__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: other - _input, "__rsub__", other=other
         ).alias("literal")
 
-    def __mul__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __mul__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__mul__(other), "__mul__", other=other
         )
 
-    def __truediv__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __truediv__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__truediv__(other), "__truediv__", other=other
         )
 
-    def __rtruediv__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __rtruediv__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: other / _input, "__rtruediv__", other=other
         ).alias("literal")
 
-    def __floordiv__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __floordiv__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__floordiv__(other), "__floordiv__", other=other
         )
 
-    def __rfloordiv__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __rfloordiv__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: other // _input, "__rfloordiv__", other=other
         ).alias("literal")
 
-    def __pow__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __pow__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__pow__(other), "__pow__", other=other
         )
 
-    def __rpow__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __rpow__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: other**_input, "__rpow__", other=other
         ).alias("literal")
 
-    def __mod__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __mod__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__mod__(other), "__mod__", other=other
         )
 
-    def __rmod__(self: Self, other: Any) -> Self:
-        return self._from_call(
+    def __rmod__(self, other: Any) -> Self:
+        return self._with_callable(
             lambda _input, other: other % _input, "__rmod__", other=other
         ).alias("literal")
 
-    def __eq__(self: Self, other: DaskExpr) -> Self:  # type: ignore[override]
-        return self._from_call(
+    def __eq__(self, other: DaskExpr) -> Self:  # type: ignore[override]
+        return self._with_callable(
             lambda _input, other: _input.__eq__(other), "__eq__", other=other
         )
 
-    def __ne__(self: Self, other: DaskExpr) -> Self:  # type: ignore[override]
-        return self._from_call(
+    def __ne__(self, other: DaskExpr) -> Self:  # type: ignore[override]
+        return self._with_callable(
             lambda _input, other: _input.__ne__(other), "__ne__", other=other
         )
 
-    def __ge__(self: Self, other: DaskExpr | Any) -> Self:
-        return self._from_call(
+    def __ge__(self, other: DaskExpr | Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__ge__(other), "__ge__", other=other
         )
 
-    def __gt__(self: Self, other: DaskExpr) -> Self:
-        return self._from_call(
+    def __gt__(self, other: DaskExpr) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__gt__(other), "__gt__", other=other
         )
 
-    def __le__(self: Self, other: DaskExpr) -> Self:
-        return self._from_call(
+    def __le__(self, other: DaskExpr) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__le__(other), "__le__", other=other
         )
 
-    def __lt__(self: Self, other: DaskExpr) -> Self:
-        return self._from_call(
+    def __lt__(self, other: DaskExpr) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__lt__(other), "__lt__", other=other
         )
 
-    def __and__(self: Self, other: DaskExpr | Any) -> Self:
-        return self._from_call(
+    def __and__(self, other: DaskExpr | Any) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__and__(other), "__and__", other=other
         )
 
-    def __or__(self: Self, other: DaskExpr) -> Self:
-        return self._from_call(
+    def __or__(self, other: DaskExpr) -> Self:
+        return self._with_callable(
             lambda _input, other: _input.__or__(other), "__or__", other=other
         )
 
-    def __invert__(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.__invert__(), "__invert__")
+    def __invert__(self) -> Self:
+        return self._with_callable(lambda _input: _input.__invert__(), "__invert__")
 
-    def mean(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.mean().to_series(), "mean")
+    def mean(self) -> Self:
+        return self._with_callable(lambda _input: _input.mean().to_series(), "mean")
 
-    def median(self: Self) -> Self:
+    def median(self) -> Self:
         from narwhals.exceptions import InvalidOperationError
 
         def func(s: dx.Series) -> dx.Series:
@@ -330,120 +313,154 @@ class DaskExpr(
                 raise InvalidOperationError(msg)
             return s.median_approximate().to_series()
 
-        return self._from_call(func, "median")
+        return self._with_callable(func, "median")
 
-    def min(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.min().to_series(), "min")
+    def min(self) -> Self:
+        return self._with_callable(lambda _input: _input.min().to_series(), "min")
 
-    def max(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.max().to_series(), "max")
+    def max(self) -> Self:
+        return self._with_callable(lambda _input: _input.max().to_series(), "max")
 
-    def std(self: Self, ddof: int) -> Self:
-        return self._from_call(
+    def std(self, ddof: int) -> Self:
+        return self._with_callable(
             lambda _input: _input.std(ddof=ddof).to_series(),
             "std",
             call_kwargs={"ddof": ddof},
         )
 
-    def var(self: Self, ddof: int) -> Self:
-        return self._from_call(
+    def var(self, ddof: int) -> Self:
+        return self._with_callable(
             lambda _input: _input.var(ddof=ddof).to_series(),
             "var",
             call_kwargs={"ddof": ddof},
         )
 
-    def skew(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.skew().to_series(), "skew")
+    def skew(self) -> Self:
+        return self._with_callable(lambda _input: _input.skew().to_series(), "skew")
 
-    def shift(self: Self, n: int) -> Self:
-        return self._from_call(lambda _input: _input.shift(n), "shift")
+    def shift(self, n: int) -> Self:
+        return self._with_callable(lambda _input: _input.shift(n), "shift")
 
-    def cum_sum(self: Self, *, reverse: bool) -> Self:
+    def cum_sum(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
             # https://github.com/dask/dask/issues/11802
             msg = "`cum_sum(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._from_call(lambda _input: _input.cumsum(), "cum_sum")
+        return self._with_callable(lambda _input: _input.cumsum(), "cum_sum")
 
-    def cum_count(self: Self, *, reverse: bool) -> Self:
+    def cum_count(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
             msg = "`cum_count(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._from_call(
+        return self._with_callable(
             lambda _input: (~_input.isna()).astype(int).cumsum(), "cum_count"
         )
 
-    def cum_min(self: Self, *, reverse: bool) -> Self:
+    def cum_min(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
             msg = "`cum_min(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._from_call(lambda _input: _input.cummin(), "cum_min")
+        return self._with_callable(lambda _input: _input.cummin(), "cum_min")
 
-    def cum_max(self: Self, *, reverse: bool) -> Self:
+    def cum_max(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
             msg = "`cum_max(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._from_call(lambda _input: _input.cummax(), "cum_max")
+        return self._with_callable(lambda _input: _input.cummax(), "cum_max")
 
-    def cum_prod(self: Self, *, reverse: bool) -> Self:
+    def cum_prod(self, *, reverse: bool) -> Self:
         if reverse:  # pragma: no cover
             msg = "`cum_prod(reverse=True)` is not supported with Dask backend"
             raise NotImplementedError(msg)
 
-        return self._from_call(lambda _input: _input.cumprod(), "cum_prod")
+        return self._with_callable(lambda _input: _input.cumprod(), "cum_prod")
 
-    def rolling_sum(
-        self: Self, window_size: int, *, min_samples: int, center: bool
-    ) -> Self:
-        return self._from_call(
+    def rolling_sum(self, window_size: int, *, min_samples: int, center: bool) -> Self:
+        return self._with_callable(
             lambda _input: _input.rolling(
                 window=window_size, min_periods=min_samples, center=center
             ).sum(),
             "rolling_sum",
         )
 
-    def sum(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.sum().to_series(), "sum")
+    def rolling_mean(self, window_size: int, *, min_samples: int, center: bool) -> Self:
+        return self._with_callable(
+            lambda _input: _input.rolling(
+                window=window_size, min_periods=min_samples, center=center
+            ).mean(),
+            "rolling_mean",
+        )
 
-    def count(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.count().to_series(), "count")
+    def rolling_var(
+        self, window_size: int, *, min_samples: int, center: bool, ddof: int
+    ) -> Self:
+        if ddof == 1:
+            return self._with_callable(
+                lambda _input: _input.rolling(
+                    window=window_size, min_periods=min_samples, center=center
+                ).var(),
+                "rolling_var",
+            )
+        else:
+            msg = "Dask backend only supports `ddof=1` for `rolling_var`"
+            raise NotImplementedError(msg)
 
-    def round(self: Self, decimals: int) -> Self:
-        return self._from_call(lambda _input: _input.round(decimals), "round")
+    def rolling_std(
+        self, window_size: int, *, min_samples: int, center: bool, ddof: int
+    ) -> Self:
+        if ddof == 1:
+            return self._with_callable(
+                lambda _input: _input.rolling(
+                    window=window_size, min_periods=min_samples, center=center
+                ).std(),
+                "rolling_std",
+            )
+        else:
+            msg = "Dask backend only supports `ddof=1` for `rolling_std`"
+            raise NotImplementedError(msg)
 
-    def unique(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.unique(), "unique")
+    def sum(self) -> Self:
+        return self._with_callable(lambda _input: _input.sum().to_series(), "sum")
 
-    def drop_nulls(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.dropna(), "drop_nulls")
+    def count(self) -> Self:
+        return self._with_callable(lambda _input: _input.count().to_series(), "count")
 
-    def abs(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.abs(), "abs")
+    def round(self, decimals: int) -> Self:
+        return self._with_callable(lambda _input: _input.round(decimals), "round")
 
-    def all(self: Self) -> Self:
-        return self._from_call(
+    def unique(self) -> Self:
+        return self._with_callable(lambda _input: _input.unique(), "unique")
+
+    def drop_nulls(self) -> Self:
+        return self._with_callable(lambda _input: _input.dropna(), "drop_nulls")
+
+    def abs(self) -> Self:
+        return self._with_callable(lambda _input: _input.abs(), "abs")
+
+    def all(self) -> Self:
+        return self._with_callable(
             lambda _input: _input.all(
                 axis=None, skipna=True, split_every=False, out=None
             ).to_series(),
             "all",
         )
 
-    def any(self: Self) -> Self:
-        return self._from_call(
+    def any(self) -> Self:
+        return self._with_callable(
             lambda _input: _input.any(axis=0, skipna=True, split_every=False).to_series(),
             "any",
         )
 
     def fill_null(
-        self: Self,
-        value: Self | Any | None,
-        strategy: Literal["forward", "backward"] | None,
+        self,
+        value: Self | NonNestedLiteral,
+        strategy: FillNullStrategy | None,
         limit: int | None,
-    ) -> DaskExpr:
+    ) -> Self:
         def func(_input: dx.Series) -> dx.Series:
             if value is not None:
                 res_ser = _input.fillna(value)
@@ -455,14 +472,14 @@ class DaskExpr(
                 )
             return res_ser
 
-        return self._from_call(func, "fillna")
+        return self._with_callable(func, "fillna")
 
     def clip(
-        self: Self,
-        lower_bound: Self | Any | None,
-        upper_bound: Self | Any | None,
+        self,
+        lower_bound: Self | NumericLiteral | TemporalLiteral | None,
+        upper_bound: Self | NumericLiteral | TemporalLiteral | None,
     ) -> Self:
-        return self._from_call(
+        return self._with_callable(
             lambda _input, lower_bound, upper_bound: _input.clip(
                 lower=lower_bound, upper=upper_bound
             ),
@@ -471,18 +488,18 @@ class DaskExpr(
             upper_bound=upper_bound,
         )
 
-    def diff(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.diff(), "diff")
+    def diff(self) -> Self:
+        return self._with_callable(lambda _input: _input.diff(), "diff")
 
-    def n_unique(self: Self) -> Self:
-        return self._from_call(
+    def n_unique(self) -> Self:
+        return self._with_callable(
             lambda _input: _input.nunique(dropna=False).to_series(), "n_unique"
         )
 
-    def is_null(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.isna(), "is_null")
+    def is_null(self) -> Self:
+        return self._with_callable(lambda _input: _input.isna(), "is_null")
 
-    def is_nan(self: Self) -> Self:
+    def is_nan(self) -> Self:
         def func(_input: dx.Series) -> dx.Series:
             dtype = native_to_narwhals_dtype(
                 _input.dtype, self._version, self._implementation
@@ -492,15 +509,13 @@ class DaskExpr(
             msg = f"`.is_nan` only supported for numeric dtypes and not {dtype}, did you mean `.is_null`?"
             raise InvalidOperationError(msg)
 
-        return self._from_call(func, "is_null")
+        return self._with_callable(func, "is_null")
 
-    def len(self: Self) -> Self:
-        return self._from_call(lambda _input: _input.size.to_series(), "len")
+    def len(self) -> Self:
+        return self._with_callable(lambda _input: _input.size.to_series(), "len")
 
     def quantile(
-        self: Self,
-        quantile: float,
-        interpolation: Literal["nearest", "higher", "lower", "midpoint", "linear"],
+        self, quantile: float, interpolation: RollingInterpolationMethod
     ) -> Self:
         if interpolation == "linear":
 
@@ -512,12 +527,12 @@ class DaskExpr(
                     q=quantile, method="dask"
                 ).to_series()  # pragma: no cover
 
-            return self._from_call(func, "quantile", quantile=quantile)
+            return self._with_callable(func, "quantile", quantile=quantile)
         else:
             msg = "`higher`, `lower`, `midpoint`, `nearest` - interpolation methods are not supported by Dask. Please use `linear` instead."
             raise NotImplementedError(msg)
 
-    def is_first_distinct(self: Self) -> Self:
+    def is_first_distinct(self) -> Self:
         def func(_input: dx.Series) -> dx.Series:
             _name = _input.name
             col_token = generate_temporary_column_name(n_bytes=8, columns=[_name])
@@ -527,9 +542,9 @@ class DaskExpr(
             first_distinct_index = frame.groupby(_name).agg({col_token: "min"})[col_token]
             return frame[col_token].isin(first_distinct_index)
 
-        return self._from_call(func, "is_first_distinct")
+        return self._with_callable(func, "is_first_distinct")
 
-    def is_last_distinct(self: Self) -> Self:
+    def is_last_distinct(self) -> Self:
         def func(_input: dx.Series) -> dx.Series:
             _name = _input.name
             col_token = generate_temporary_column_name(n_bytes=8, columns=[_name])
@@ -539,9 +554,9 @@ class DaskExpr(
             last_distinct_index = frame.groupby(_name).agg({col_token: "max"})[col_token]
             return frame[col_token].isin(last_distinct_index)
 
-        return self._from_call(func, "is_last_distinct")
+        return self._with_callable(func, "is_last_distinct")
 
-    def is_unique(self: Self) -> Self:
+    def is_unique(self) -> Self:
         def func(_input: dx.Series) -> dx.Series:
             _name = _input.name
             return (
@@ -551,18 +566,18 @@ class DaskExpr(
                 == 1
             )
 
-        return self._from_call(func, "is_unique")
+        return self._with_callable(func, "is_unique")
 
-    def is_in(self: Self, other: Any) -> Self:
-        return self._from_call(lambda _input: _input.isin(other), "is_in")
+    def is_in(self, other: Any) -> Self:
+        return self._with_callable(lambda _input: _input.isin(other), "is_in")
 
-    def null_count(self: Self) -> Self:
-        return self._from_call(
+    def null_count(self) -> Self:
+        return self._with_callable(
             lambda _input: _input.isna().sum().to_series(), "null_count"
         )
 
     def over(
-        self: Self,
+        self,
         partition_by: Sequence[str],
         order_by: Sequence[str] | None,
     ) -> Self:
@@ -583,6 +598,10 @@ class DaskExpr(
                 "https://narwhals-dev.github.io/narwhals/pandas_like_concepts/improve_group_by_operation/"
             )
             raise NotImplementedError(msg)
+        elif order_by:
+            # Wrong results https://github.com/dask/dask/issues/11806.
+            msg = "`over` with `order_by` is not yet supported in Dask."
+            raise NotImplementedError(msg)
         else:
             function_name = PandasLikeGroupBy._leaf_name(self)
             try:
@@ -605,12 +624,21 @@ class DaskExpr(
                         message=".*`meta` is not specified",
                         category=UserWarning,
                     )
-                    res_native = df._native_frame.groupby(partition_by)[
-                        list(output_names)
-                    ].transform(dask_function_name, **self._call_kwargs)
-                result_frame = df._from_native_frame(
+                    grouped = df.native.groupby(partition_by)
+                    if dask_function_name == "size":
+                        if len(output_names) != 1:  # pragma: no cover
+                            msg = "Safety check failed, please report a bug."
+                            raise AssertionError(msg)
+                        res_native = grouped.transform(
+                            dask_function_name, **self._call_kwargs
+                        ).to_frame(output_names[0])
+                    else:
+                        res_native = grouped[list(output_names)].transform(
+                            dask_function_name, **self._call_kwargs
+                        )
+                result_frame = df._with_native(
                     res_native.rename(columns=dict(zip(output_names, aliases)))
-                )._native_frame
+                ).native
                 return [result_frame[name] for name in aliases]
 
         return self.__class__(
@@ -623,29 +651,26 @@ class DaskExpr(
             version=self._version,
         )
 
-    def cast(self: Self, dtype: DType | type[DType]) -> Self:
+    def cast(self, dtype: DType | type[DType]) -> Self:
         def func(_input: dx.Series) -> dx.Series:
             native_dtype = narwhals_to_native_dtype(dtype, self._version)
             return _input.astype(native_dtype)
 
-        return self._from_call(func, "cast")
+        return self._with_callable(func, "cast")
 
-    def is_finite(self: Self) -> Self:
+    def is_finite(self) -> Self:
         import dask.array as da
 
-        return self._from_call(da.isfinite, "is_finite")
+        return self._with_callable(da.isfinite, "is_finite")
 
     @property
-    def str(self: Self) -> DaskExprStringNamespace:
+    def str(self) -> DaskExprStringNamespace:
         return DaskExprStringNamespace(self)
 
     @property
-    def dt(self: Self) -> DaskExprDateTimeNamespace:
+    def dt(self) -> DaskExprDateTimeNamespace:
         return DaskExprDateTimeNamespace(self)
 
-    @property
-    def name(self: Self) -> DaskExprNameNamespace:
-        return DaskExprNameNamespace(self)
-
     list = not_implemented()  # pyright: ignore[reportAssignmentType]
     struct = not_implemented()  # pyright: ignore[reportAssignmentType]
+    rank = not_implemented()  # pyright: ignore[reportAssignmentType]
